liblzma: General-purpose data compression software
==================================================

Description
-----------

This packages represents liblzma, a part of XZ Utils, the free general-purpose
data compression software with a high compression ratio.

License
-------

Some parts public domain, other parts GNU LGPLv2.1, GNU GPLv2, or GNU
GPLv3.


Upstream Contact
----------------

http://tukaani.org/xz/

